package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcDyManage;
import com.ruoyi.szxc.mapper.SzxcDyManageMapper;
import com.ruoyi.szxc.service.ISzxcDyManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 党员管理Service业务层处理
 * 
 * @author hs
 * @date 2024-03-22
 */
@Service
public class SzxcDyManageServiceImpl implements ISzxcDyManageService 
{
    @Autowired
    private SzxcDyManageMapper szxcDyManageMapper;

    /**
     * 查询党员管理
     * 
     * @param id 党员管理主键
     * @return 党员管理
     */
    @Override
    public SzxcDyManage selectSzxcDyManageById(Long id)
    {
        return szxcDyManageMapper.selectSzxcDyManageById(id);
    }

    /**
     * 查询党员管理列表
     * 
     * @param szxcDyManage 党员管理
     * @return 党员管理
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<SzxcDyManage> selectSzxcDyManageList(SzxcDyManage szxcDyManage)
    {
        return szxcDyManageMapper.selectSzxcDyManageList(szxcDyManage);
    }

    /**
     * 新增党员管理
     * 
     * @param szxcDyManage 党员管理
     * @return 结果
     */
    @Override
    public int insertSzxcDyManage(SzxcDyManage szxcDyManage)
    {
        szxcDyManage.setCreateTime(DateUtils.getNowDate());
        return szxcDyManageMapper.insertSzxcDyManage(szxcDyManage);
    }

    /**
     * 修改党员管理
     * 
     * @param szxcDyManage 党员管理
     * @return 结果
     */
    @Override
    public int updateSzxcDyManage(SzxcDyManage szxcDyManage)
    {
        szxcDyManage.setUpdateTime(DateUtils.getNowDate());
        return szxcDyManageMapper.updateSzxcDyManage(szxcDyManage);
    }

    /**
     * 批量删除党员管理
     * 
     * @param ids 需要删除的党员管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcDyManageByIds(Long[] ids)
    {
        return szxcDyManageMapper.deleteSzxcDyManageByIds(ids);
    }

    /**
     * 删除党员管理信息
     * 
     * @param id 党员管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcDyManageById(Long id)
    {
        return szxcDyManageMapper.deleteSzxcDyManageById(id);
    }
}
